@@ -23,6 +23,7 @@ from .._vendor.auxlib.collection import first
 from .._vendor.auxlib.ish import dals
 from ..base.context import context
 from ..common.compat import ensure_text_type, iteritems, itervalues, on_win, text_type
+from ..common.io import time_recorder
 from ..common.path import (explode_directories, get_all_directories, get_bin_directory_short_path,
                            get_major_minor_version,
                            get_python_site_packages_short_path)
@@ -237,6 +238,7 @@ class UnlinkLinkTransaction(object):
                     path, tuple(Dist(axn.linked_package_record) for axn in axns), context
                 )
 
+    @time_recorder("unlink_link_prepare_and_verify")
     def verify(self):
         if not self._prepared:
             self.prepare()
@@ -273,7 +275,7 @@ class UnlinkLinkTransaction(object):
                                  "Check that you have sufficient permissions."
                                  "" % self.target_prefix)
 
-        with signal_handler(conda_signal_handler):
+        with signal_handler(conda_signal_handler), time_recorder("unlink_link_execute"):
             pkg_idx = 0
             try:
                 for pkg_idx, (pkg_data, actions) in enumerate(self.all_actions):
