@@ -21,6 +21,7 @@ from .base.context import context
 from .cli import common
 from .cli.common import pkg_if_in_private_env, prefix_if_in_private_env
 from .common.compat import odict, on_win
+from .common.io import time_recorder
 from .common.path import (is_private_env, preferred_env_matches_prefix,
                           preferred_env_to_prefix, prefix_to_env_name)
 from .core.index import _supplement_index_with_prefix
@@ -368,7 +369,7 @@ def add_defaults_to_specs(r, linked, specs, update=False, prefix=None):
     # TODO: This should use the pinning mechanism. But don't change the API because cas uses it
     if r.explicit(specs) or is_private_env(prefix):
         return
-    log.debug('H0 specs=%r' % specs)
+    log.debug('H0 specs=%r' % (specs,))
     names_linked = {r.package_name(d): d for d in linked if d in r.index}
     mspecs = list(map(MatchSpec, specs))
 
@@ -414,7 +415,7 @@ def add_defaults_to_specs(r, linked, specs, update=False, prefix=None):
 
         if def_ver is not None:
             specs.append('%s %s*' % (name, def_ver))
-    log.debug('HF specs=%r' % specs)
+    log.debug('HF specs=%r' % (specs,))
 
 
 def get_pinned_specs(prefix):
@@ -442,6 +443,7 @@ SpecForEnv = namedtuple('DistForEnv', ['env', 'spec'])
 SpecsForPrefix = namedtuple('DistsForPrefix', ['prefix', 'specs', 'r'])
 
 
+@time_recorder("install_actions")
 def install_actions(prefix, index, specs, force=False, only_names=None, always_copy=False,
                     pinned=True, minimal_hint=False, update_deps=True, prune=False,
                     channel_priority_map=None, is_update=False):  # pragma: no cover
@@ -462,6 +464,7 @@ def install_actions(prefix, index, specs, force=False, only_names=None, always_c
     return actions
 
 
+@time_recorder("install_actions_list")
 def install_actions_list(prefix, index, specs, force=False, only_names=None, always_copy=False,
                          pinned=True, minimal_hint=False, update_deps=True, prune=False,
                          channel_priority_map=None, is_update=False):
@@ -604,14 +607,11 @@ def match_to_original_specs(specs, specs_for_prefix):
     matches_any_spec = lambda dst: next(spc for spc in specs if spc.name == dst)
     matched_specs_for_prefix = []
     for prefix_with_dists in specs_for_prefix:
-        linked = linked_data(prefix_with_dists.prefix)
-        r = prefix_with_dists.r
         new_matches = []
         for spec in prefix_with_dists.specs:
             matched = matches_any_spec(spec)
             if matched:
                 new_matches.append(matched)
-        add_defaults_to_specs(r, linked, new_matches, prefix=prefix_with_dists.prefix)
         matched_specs_for_prefix.append(SpecsForPrefix(
             prefix=prefix_with_dists.prefix, r=prefix_with_dists.r, specs=new_matches))
     return matched_specs_for_prefix
@@ -626,13 +626,14 @@ def get_actions_for_dists(specs_by_prefix, only_names, index, force, always_copy
     specs = augment_specs(prefix, specs, pinned)
 
     linked = linked_data(prefix)
-    must_have = odict()
+    add_defaults_to_specs(r, linked, specs, prefix)
 
     installed = linked
     if prune:
         installed = []
     pkgs = r.install(specs, installed, update_deps=update_deps)
 
+    must_have = odict()
     for fn in pkgs:
         dist = Dist(fn)
         name = r.package_name(dist)
@@ -736,7 +737,7 @@ def augment_specs(prefix, specs, pinned=True):
     if context.track_features:
         specs.extend(x + '@' for x in context.track_features)
 
-    return tuple(specs)
+    return list(specs)
 
 
 def remove_actions(prefix, specs, index, force=False, pinned=True):
@@ -824,6 +825,7 @@ def revert_actions(prefix, revision=-1, index=None):
 
 # ---------------------------- EXECUTION --------------------------
 
+@time_recorder("execute_actions")
 def execute_actions(actions, index, verbose=False):
     plan = plan_from_actions(actions, index)
     with History(actions[PREFIX]):
@@ -848,6 +850,7 @@ def update_old_plan(old_plan):
     return plan
 
 
+@time_recorder("execute_plan")
 def execute_plan(old_plan, index=None, verbose=False):
     """
     Deprecated: This should `conda.instructions.execute_instructions` instead
